@@ -26,18 +26,18 @@ import datetime
 import gobject
 import platform
 
-import dbus
-import dbus.service
 
 from elisa.core import __version__, version_info
 from elisa.core.config import Config, ConfigError
 from elisa.core.log import Loggable
 from elisa.core.utils import exception_hook, misc
+from elisa.core.utils.splash_screen import SplashScreen
 from elisa.core import bus
 
 from elisa.core.components.message import Message
 
 from elisa.core import config_upgrader
+from elisa.core.launcher import plugin_directories
 from elisa.core.plugin_registry import PluginRegistry
 from elisa.core import input_manager, service_manager
 from elisa.core import metadata_manager, resource_manager
@@ -57,71 +57,12 @@ try:
 except ImportError:
     store = None
 
-try:
-    from elisa.core.utils.update_checker import UpdateChecker
-except ImportError:
-    # could happen if the elisa http client plugin is missing
-    UpdateChecker = None
-
+# import the default configuration and settings
+from elisa.core.default_config import CONFIG_DIR, DEFAULT_CONFIG, \
+        PICTURES_CACHE, CONFIG_FILE
 
 from distutils.version import LooseVersion
 
-CONFIG_DIR = os.path.join(os.path.expanduser('~'), ".elisa-0.5")
-
-# We add to the configuration file name the version number in order to bypass
-# the configuration upgrade system. Direct consequences:
-# - custom user configuration is lost between releases
-# - prevents configuration upgrade bugs
-# - avoid configuration upgrade work
-#version_string = "_".join([str(n) for n in version_info])
-#CONFIG_FILE = "elisa_%s.conf" % version_string
-
-# FIXME: hardcoded configuration file name in order to avoid its rewriting
-# starting from Elisa 0.5.6; this is a temporary solution that is valid for
-# the moment given that there is no configuration to upgrade for now.
-CONFIG_FILE = "elisa_0_5_6.conf"
-
-TRANS_FILE = "data/translations.lst"
-PICTURES_CACHE = os.path.join(CONFIG_DIR, 'pictures_cache')
-
-DEFAULT_CONFIG = """\
-[general]
-version = '%(version)s'
-install_date = '%(install_date)s'
-frontends = ['frontend1']
-disabled_plugins = []
-# database connection string. see https://storm.canonical.com/Manual
-database = '%(database_uri)s'
-
-[frontend1]
-frontend = 'pigment.pigment_frontend:PigmentFrontend'
-theme = 'elisa.plugins.hp'
-controller_path = '/poblesec'
-
-[directories]
-video = ['*default*']
-pictures = ['*default*']
-music = ['*default*']
-
-[poblesec.main:PoblesecController]
-viewport_buttons_mode = 'embedded'
-
-[poblesec.player_audio:AudioPlayerController]
-visualization = ''
-osd_timeout = '0'
-audio_sink = 'gconfaudiosink'
-
-[poblesec.player_video:VideoPlayerController]
-audio_sink = 'gconfaudiosink'
-"""
-
-def setup_output_redirection(directory_path, log_filename=None):
-    # See http://www.py2exe.org/index.cgi/StderrLog
-    log_filename = log_filename or "elisa.log"
-    elisa_log = os.path.join(directory_path, log_filename)
-    sys.stdout = open(elisa_log, "w")
-    sys.stderr = open(elisa_log, "w")
-
 
 class ComponentsLoadedMessage(Message):
     """
@@ -146,34 +87,29 @@ class NewElisaVersionMessage(Message):
         self.installer_url = installer_url
 
 
-class FirstRunMessage(Message):
-    """
-    Sent when Elisa detects it is the first time it is being run.
-    """
-
-
 class BaseApplication(Loggable):
+    """
+    @ivar first_run:            wether or not the Application is being executed for the
+                                first time.
+    @type first_run:            C{bool}
+    """
+
     config = None
     plugin_registry = None
-    bus = None
-    metadata_manager = None
-    service_manager = None
-    input_manager = None
-    store = None
 
-    def __init__(self, config, plugin_directories):
+    def __init__(self, options, plugin_directories):
         # we do this here and not in initialize() as this needs to be done as
         # soon as possible
         super(BaseApplication, self).__init__()
 
-        self._first_run = False
+        from elisa.core import log
+        log.init()
+
+        self.first_run = False
+        config = options['config-file']
         self._config_filename = self._get_config_filename(config)
         if not os.path.exists(self._config_filename):
-            self._first_run = True
-
-        # if running frozen on win32, redirect stdout/stderr to $CONFIG_DIR/elisa.log
-        if hasattr(sys, "frozen"):
-            setup_output_redirection(os.path.dirname(self._config_filename))
+            self.first_run = True
 
         self.config, self._install_date, self._user_id = self._load_config(config)
         self.plugin_registry = self._create_plugin_registry(plugin_directories)
@@ -182,7 +118,7 @@ class BaseApplication(Loggable):
         disabled_plugins = self.config.get_option('disabled_plugins',
                                                   section='general',
                                                   default=[])
-        plugin_registry = PluginRegistry(plugin_directories)
+        plugin_registry = PluginRegistry(self.config, plugin_directories)
         plugin_registry.load_plugins(disabled_plugins)
         return plugin_registry
 
@@ -234,13 +170,30 @@ class BaseApplication(Loggable):
         user_id = cfg.get_option('user_id', section='general', default='')
         return (cfg, install_date, user_id)
 
+    def is_power_user(self):
+        """
+        Return whether the user is a "power user".
+
+        A power user has access to advanced functionality, e.g. advanced
+        configuration settings in the UI or installation of unstable plugins.
+        Some advanced features may be unstable, the power user will use them at
+        his own risk.
+
+        @return: whether the user is a "power user"
+        @rtype:  C{bool}
+        """
+        option = self.config.get_option('power_user', section='general',
+                                        default='0')
+        # All other values than '1' translate to False.
+        return (option == '1')
+
 
 class Application(BaseApplication):
     """ Application is the entry point of Elisa. It groups all the necessary
     elements needed for Elisa to run. It is in charge of instantiating a
     Config and a PluginRegistry. Application also provides access to
     input events and data, and holds the user interfaces.
- 
+
     @ivar plugin_registry:      loads and manages the plugins
     @type plugin_registry:      L{elisa.core.plugin_registry.PluginRegistry}
     @ivar config:               Application's configuration file, storing options
@@ -266,49 +219,43 @@ class Application(BaseApplication):
 
     log_category = "application"
 
-    def __init__(self, config_filename=None, show_tracebacks=False,
-                 splash=None, options=None):
-        """
-        @param config_filename: the config filename to use. Can be absolute
-                                or relative path
-        @type config_filename:  string or None to use default config file
-        """
-        default_path = os.path.join(CONFIG_DIR, 'plugins')
-        paths = os.environ.get('ELISA_PLUGIN_PATH', default_path).split(os.path.pathsep)
-        paths = [p for p in paths if p != '']
-        if default_path not in paths:
-            paths.insert(0, default_path)
-
-        super(Application, self).__init__(config_filename, paths)
+    def __init__(self, options):
+        super(Application, self).__init__(options, plugin_directories)
+        
+        if SplashScreen is None or options['nosplash']:
+            self._splash = None
+        else:
+            self._splash = SplashScreen()
+            self._splash.show()
 
         # load the exception hook asap
-        self.show_tracebacks = show_tracebacks
+        self.show_tracebacks = True
         self._load_exception_hook()
 
         self.debug("Creating")
         self.running = False
-        self._splash = splash
 
         self.store = None
         self.update_checker = None
 
         self.bus = bus.Bus()
+
         self.service_manager = service_manager.ServiceManager()
         self.metadata_manager = metadata_manager.MetadataManager()
         self.resource_manager = resource_manager.ResourceManager()
         self.input_manager = input_manager.InputManager()
+
+        for manager in (self.service_manager, self.metadata_manager,
+                        self.resource_manager, self.input_manager):
+            self.plugin_registry.register_plugin_status_changed_callback(manager.plugin_status_changed_cb)
+
         self.interface_controller = interface_controller.InterfaceController()
         self.options = options
 
-        if self._first_run:
-            # First time elisa is run with this configuration, we want to
-            # notify other components (so that the frontend can run a
-            # configuration wizard for instance).
-            self.bus.send_message(FirstRunMessage())
-
         import platform
         system = platform.system()
         if system == 'Windows':
+            # FIXME: the core should not depend on plugins!!!
             from elisa.plugins.poblesec.windows_message import WindowsMessageSource
             from win32con import WM_COPYDATA
             self.windows_message_source = WindowsMessageSource()
@@ -434,49 +381,21 @@ class Application(BaseApplication):
         # interface controller
         self.media_directories = MediaDirectoryHelper()
 
-        def loading_providers_done(result):
+        def initialize_interface(result):
             return self.interface_controller.initialize()
 
-        managers = ( # manager, entry_point
-                    (self.resource_manager, 'resource_provider'),
-                    (self.service_manager, 'service_provider'),
-                    (self.metadata_manager, 'metadata_provider'),
-                    (self.input_manager, 'input_provider'),
-                   )
+        def enable_plugins(result):
+            # Enable all the loaded plugins
+            return self.plugin_registry.enable_plugins()
 
-        def iter_managers(managers):
-            for manager, entry_point in managers:
-                entry_point = 'elisa.core.components.' + entry_point
-                self.debug("Loading providers for manager %s" % manager)
-
-                providers = []
-                for entry in pkg_resources.iter_entry_points(entry_point):
-                    # FIXME: consider only "enabled plugins"
-                    component_name = '%s:%s' % (entry.module_name,
-                            '.'.join(entry.attrs))
-
-                    providers.append(component_name)
-
-                if not providers:
-                    self.debug("No providers to load for manager %s" % manager)
-                    continue
-
-                dfr = manager.load_components(providers)
-                yield dfr
-        
-        def load_managers(db, managers):
-            return task.coiterate(iter_managers(managers)).addCallback(
-                    loading_providers_done)
-
-        def interface_initialized(result):
-            # Now that db/plugins are loaded, we can safely register dbus service name
-            self.dbus_name = dbus.service.BusName('com.fluendo.Elisa', dbus.SessionBus())
+        def ready(result):
             self.bus.send_message(ComponentsLoadedMessage())
             self._close_splash_screen()
 
         dfr = self.initialize_db()
-        dfr.addCallback(load_managers, managers)
-        dfr.addCallback(interface_initialized)
+        dfr.addCallback(initialize_interface)
+        dfr.addCallback(enable_plugins)
+        dfr.addCallback(ready)
         return dfr
 
     def initialize_db(self):
@@ -498,27 +417,41 @@ class Application(BaseApplication):
         self.store = store.DeferredStore(db, auto_reload=False)
         return self.store.start()
 
-
     def start(self):
-        """ Execute the application. Start the Managers and the
-        InterfaceController.
         """
-        if hasattr(gobject, 'set_prgname') == True:
+        Execute the application.
+
+        Start the bus and the update checker.
+        """
+        if hasattr(gobject, 'set_prgname'):
             gobject.set_prgname('elisa')
 
         self.running = True
         self.info("Starting")
-        self.bus.start()
-        self.input_manager.start()
-        self.metadata_manager.start()
-        self.resource_manager.start()
-        self.service_manager.start()
 
-        if UpdateChecker:
+        self.bus.start()
+
+        if platform.system() == 'Windows':
+            from mswin32.tools import should_install_recommended_plugins
+            self.config.set_option('auto_install_new_recommended_plugins',
+                                   should_install_recommended_plugins(),
+                                   section='plugin_registry')
+
+        try:
+            # Do not do the import at the beginning of the file as the update
+            # checker currently depends on the http client plugin.
+            # FIXME: the core should not depend on plugins!!!
+            from elisa.core.utils.update_checker import UpdateChecker
+        except ImportError:
+            # Could happen if the elisa http client plugin is missing
+            pass
+        else:
             self.update_checker = UpdateChecker(self._install_date,
                     self._user_id,  __version__)
             self.update_checker.start(self._update_check_callback)
 
+        return defer.succeed(True)
+
     def stop(self, stop_reactor=True):
         """
         Stop the application.
@@ -536,9 +469,9 @@ class Application(BaseApplication):
             self.info("Stopping managers")
 
             manager_deferreds = []
-            for manager in (self.service_manager, self.metadata_manager,
-                            self.input_manager, self.resource_manager):
-                manager_deferreds.append(defer.maybeDeferred(manager.stop))
+            for manager in (self.metadata_manager, self.resource_manager,
+                            self.service_manager, self.input_manager):
+                manager_deferreds.append(manager.clean())
             if self.store:
                 # FIXME: store is not closed properly: self.store.stop should be
                 # called after the commit
@@ -564,10 +497,12 @@ class Application(BaseApplication):
                     # - fix the locks in gst_metadata when it is out of process
                     reactor.fireSystemEvent('shutdown')
                     from mswin32 import tools
-                    tools.kill_process('elisa_fork')
-                    tools.kill_process('elisa')
-                    import win32process
-                    win32process.ExitProcess(0)
+                    try:
+                        tools.exit()
+                    except AssertionError:
+                        # Running elisa uninstalled
+                        import win32process
+                        win32process.ExitProcess(0)
                 else:
                     reactor.stop()
 
@@ -603,8 +538,9 @@ class Application(BaseApplication):
         memmove(addressof(commandlinedata), copydata.lpData, sizeof(commandlinedata))
         frontend = self.interface_controller.frontends.values()[0]
         main = frontend.retrieve_controllers('/poblesec')[0]
-        files = commandlinedata.data.split(" ")
+        # We use '|' as a file separator
+        files = commandlinedata.data.split('|')
         if len(files) > 0:
-            main.play_file(files[0])
+            main.play_files(files)
         
         return True
