@@ -13,16 +13,14 @@
 # agreement from Fluendo.
 # See "LICENSE.Elisa" in the root directory of this distribution package
 # for details on that license.
+#
+# Authors: Philippe Normand <philippe@fluendo.com>
+#          Florian Boucault <florian@fluendo.com>
 
 """
-Input events providers Component base classes
+Input events providers base classes.
 """
 
-
-__maintainer__ = 'Philippe Normand <philippe@fluendo.com>'
-__maintainer2__ = 'Florian Boucault <florian@fluendo.com>'
-
-
 from elisa.core.component import Component
 
 
@@ -42,6 +40,7 @@ class InputProvider(Component):
         @returns:    L{elisa.core.input_event.InputEvent}
         """
 
+
 class PollInputProvider(InputProvider):
     """ Non-blocking way to retrieve user input events. Plugins can
     provide InputProviders to support new input devices (remote
@@ -60,6 +59,7 @@ class PollInputProvider(InputProvider):
         """
         return []
 
+
 class PushInputProvider(InputProvider):
     """ InputProvider that will be able to push InputEvents directly
     to the InputManager by method calls
