@@ -13,14 +13,14 @@
 # agreement from Fluendo.
 # See "LICENSE.Elisa" in the root directory of this distribution package
 # for details on that license.
+#
+# Authors:  Philippe Normand <philippe@fluendo.com>
+#
 
 """
 Config management module
 """
 
-
-__maintainer__ = 'Philippe Normand <philippe@fluendo.com>'
-
 # FIXME: without this line configobj.OPTION_DEFAULTS is None in some tests..
 # EEK!
 from elisa.extern import configobj
