@@ -30,7 +30,7 @@ import sys
 from twisted.internet import defer
 from twisted.internet import threads
 
-from elisa.core.application import CONFIG_DIR
+from elisa.core.default_config import CONFIG_DIR
 from elisa.core.epm.exceptions import *
 
 from elisa.core.log import Loggable
