@@ -38,7 +38,7 @@ from distutils.dist import Distribution
 from twisted.internet import defer
 from twisted.internet import threads
 
-from elisa.core.application import CONFIG_DIR, CONFIG_FILE
+from elisa.core.default_config import CONFIG_DIR, CONFIG_FILE
 from elisa.core.plugin_registry import PluginRegistry
 from elisa.core.config import Config
 from elisa.extern.epr.egg_parser import EggParser
@@ -113,7 +113,7 @@ class EggRegistry(Loggable):
         if common.application:
             self.plugin_registry = common.application.plugin_registry
         else:
-            self.plugin_registry = PluginRegistry(self.plugin_dirs)
+            self.plugin_registry = PluginRegistry(Config(), self.plugin_dirs)
 
     def _load_static_repositories(self):
         # FIXME: get static repositories' sources from config file.
