@@ -27,7 +27,7 @@ from elisa.core.epm.exceptions import *
 from elisa.core.epm.egg_plugin import EggPlugin
 from elisa.core import common
 from elisa.core.utils import misc
-from elisa.core.application import CONFIG_DIR
+from elisa.core.default_config import CONFIG_DIR
 
 from twisted.web import xmlrpc
 from twisted.web import client
