@@ -45,7 +45,8 @@ class Options(usage.Options):
 
     optParameters = [['import', 'i', None, 'The script to import, used by \
                                             windows only.'],
-                     ['config-file', 'c', None, 'The configuration file.']
+                     ['config-file', 'c', None, 'The configuration file.'],
+                     ['rss', None, None, 'A rss link']
                     ]
 
 
