@@ -13,73 +13,83 @@
 # agreement from Fluendo.
 # See "LICENSE.Elisa" in the root directory of this distribution package
 # for details on that license.
+#
+# Authors: Florian Boucault <florian@fluendo.com>
+#          Benjamin Kampmann <benjamin@fluendo.com>
 
 """
-manage resource providers and allow to access resources specified by a
-certain uri
+Manage resource providers and allow to access resources specified by a
+certain uri.
 """
 
-
-__maintainer__ = 'Florian Boucault <florian@fluendo.com>'
-__maintainter2__ = 'Benjamin Kampmann <benjamin@fluendo.com>'
-
 from elisa.core.manager import Manager
-
 from elisa.core.component import get_component_path
 
 import re
 
+
 class ResourceProviderNotFound(Exception):
 
     """
-    This exception is raised when the requested resource provider is not
-    registered.
+    Raised when the requested resource provider is not registered.
     """
 
     def __init__(self, path):
         Exception.__init__(self, 'Resource provider %s not registered' % path)
 
+
 class NoMatchingResourceProvider(Exception):
 
     """
-    This exception is raised when no resource provider matches the given URI.
+    Raised when no resource provider matches the given URI.
     """
 
     def __init__(self, uri):
         Exception.__init__(self, 'No resource provider found for URI %s' % uri)
 
+
 class ResourceManager(Manager):
+
     """
-    Provide access to resources through the use of ResourceProvider components
-    which make use of various data sources.
+    Provide access to resources through the use of C{ResourceProvider}
+    components that make use of various data sources.
     """
 
+    entry_point = 'elisa.core.components.resource_provider'
+
     def __init__(self):
-        """ Initialize resource providers
-        """
-        Manager.__init__(self)
+        super(ResourceManager, self).__init__()
 
         # list of couples (compiled regular expression, resource provider)
         self._providers_uri_regexps = []
 
     def register_component(self, component):
-        Manager.register_component(self, component)
+        dfr = super(ResourceManager, self).register_component(component)
 
-        if hasattr(component, 'supported_uri') and \
+        def registered(result):
+            if hasattr(component, 'supported_uri') and \
                                         len(component.supported_uri) is not 0:
-            uri_regexp = re.compile(component.supported_uri)
-            self._providers_uri_regexps.append((uri_regexp, component))
+                uri_regexp = re.compile(component.supported_uri)
+                self._providers_uri_regexps.append((uri_regexp, component))
+
+        dfr.addCallback(registered)
+        return dfr
 
     def unregister_component(self, component):
-        Manager.unregister_component(self, component)
+        dfr = super(ResourceManager, self).unregister_component(component)
 
-        # find the regular expression if in there
-        for index, regexp_provider in enumerate(self._providers_uri_regexps):
-            regexp, provider = regexp_provider
-            if provider is component:
-                # Found, remove it
-                self._providers_uri_regexps.pop(index)
-                return
+        def pop_regexp(result):
+            # find the regular expression if in there
+            for index, regexp_provider in \
+                enumerate(self._providers_uri_regexps):
+                regexp, provider = regexp_provider
+                if provider is component:
+                    # Found, remove it
+                    self._providers_uri_regexps.pop(index)
+                    break
+
+        dfr.addCallback(pop_regexp)
+        return dfr
 
     def get_resource_provider_by_path(self, path):
         """
@@ -94,7 +104,7 @@ class ResourceManager(Manager):
         @param path: the full component path for the resource provider
         @type path:  C{str}
         """
-        for provider in self._components:
+        for provider in self.components:
             if get_component_path(provider.__class__) == path:
                 return provider
         raise ResourceProviderNotFound(path)
