@@ -13,12 +13,13 @@
 # See "LICENSE.Elisa" in the root directory of this distribution package
 # for details on that license.
 
-from elisa.core.tests.elisa_test_case import ElisaTestCase
+from twisted.trial.unittest import TestCase
 from elisa.core.components.input_provider import PushInputProvider, \
                                                  PollInputProvider
 from elisa.core.input_manager import InputManager
+from twisted.internet import defer
 
-class TestInputManager(ElisaTestCase):
+class TestInputManager(TestCase):
 
     def test_registering_unregister_push(self):
         """
@@ -124,20 +125,7 @@ class TestInputManager(ElisaTestCase):
         input_manager._poll_events()
 
         self.assertTrue(event_call.called)
-
-    def test_corrupted_provider(self):
-        """
-        check that everything is fine with a corrupted provider
-        """
-            
-        class WrongProvider(object):
-            path = 'wrong_provider'
-        
-        input_manager = InputManager()
-        input_manager.register_component(WrongProvider())
-
-        # should filter out only PollProviders, so it shouldn't brake
-        input_manager._poll_events()
+        return input_manager.clean()
 
     def test_processing_breaks(self):
         """
@@ -170,39 +158,3 @@ class TestInputManager(ElisaTestCase):
         self.assertTrue(call1.called)
         self.assertTrue(callfails.called)
         self.assertTrue(call2.called)
-
-    def test_start_stop(self):
-        """
-        test if the poll loop gets set up and stopped on start and stop
-        """
-        input_manager = InputManager()
-        # start condition
-        self.assertFalse(input_manager._poll_call.running)
-
-        input_manager.start()
-        # no poll providers so polling is not started
-        self.assertFalse(input_manager._poll_call.running)
-        
-        class SimplePollProvider(PollInputProvider):
-            def get_input_events(self):
-                return ('pocahontas',)
-
-        # add a poll provider, polling should start
-        component = SimplePollProvider()
-        input_manager.register_component(component)
-        self.assertTrue(input_manager._poll_call.running)
-
-        # stop
-        input_manager.stop()
-        self.assertFalse(input_manager._poll_call.running)
-        
-        # start again, this time the polling should start as there's a poll
-        # provider
-        component = SimplePollProvider()
-        input_manager.register_component(component)
-        input_manager.start()
-        self.assertTrue(input_manager._poll_call.running)
-
-        # after removing the last poll provider, polling should stop
-        input_manager.unregister_component(component)
-        self.assertFalse(input_manager._poll_call.running)
