@@ -13,23 +13,22 @@
 # See "LICENSE.Elisa" in the root directory of this distribution package
 # for details on that license.
 
-from elisa.base_components import input_provider
+from elisa.core.components import input_provider
 from elisa.core import input_event
 from elisa.core.tests.elisa_test_case import ElisaTestCase
 
 def create_input_event(data, component_source):
-    source, typ, value, action = data
+    source, typ, value = data
     source = getattr(input_event.EventSource, source)
     value = getattr(input_event.EventValue, value)
     typ = getattr(input_event.EventType, typ)
-    evt = input_event.InputEvent(input_event.EventSource.MOUSE, typ,
-                                 action, value,  source_id=source)
+    evt = input_event.InputEvent(input_event.EventSource.MOUSE, typ, value)
     evt.component_source = component_source
     return evt
 
 
-EVTS = [ ('MOUSE', 'MOUSE_DOWN', 'MOUSE_LEFT', 'PAUSE'),
-         ('MOUSE', 'MOUSE_UP',   'MOUSE_LEFT', 'PLAY')
+EVTS = [ ('MOUSE', 'MOUSE_DOWN', 'MOUSE_LEFT'),
+         ('MOUSE', 'MOUSE_UP',   'MOUSE_LEFT')
          ]
 
 
@@ -56,14 +55,14 @@ class MousePushInputProvider(input_provider.PushInputProvider):
 
     def trigger_some_events(self):
         for evt in [self.create_input_event(data) for data in EVTS]:
-            self.input_manager.process_event(evt, self.path)
+            self.input_manager.process_event(evt)
 
 class FakeManager:
 
     up_ok = False
     down_ok = False
 
-    def process_event(self, event, path):
+    def process_event(self, event):
         if event.type == input_event.EventType.MOUSE_UP and \
            event.value == input_event.EventValue.MOUSE_LEFT:
             self.up_ok = True
