@@ -167,10 +167,15 @@ class TestMediaURI(ElisaTestCase):
 ##         self.assertEqual(str(uri), misc.fs_encode(u))
 
     def test_no_unicode(self):
+        # FIXME: this fails with LANG=C environment
         u = 'file:///Vidéos'
         uri = media_uri.MediaUri(u)
+        # FIXME: this is not a unit test for the media_uri as it stands and
+        # fails with the not unit tested local_helper.system_encoding method
         self.assertEqual(unicode(uri), unicode(u, locale_helper.system_encoding()))
 
+    test_no_unicode.todo = "refactor test"
+
     def test_parameters(self):
         location = u'http://192.168.2.69:10243/WMCv2/%7b9B3A580F-68E8-4701-B8D8-9708E6E5E4F6%7d/103-1.wma?format=PCM'
         uri = media_uri.MediaUri(location)
@@ -299,6 +304,7 @@ class TestMediaURI(ElisaTestCase):
         self.assertEqual(repr(uri), u'file://%s/test/toto' % cwd)
 
     def test_uri_parts(self):
+        # FIXME: this fails with LANG=C
         uri_parts = {}
         uri_parts['scheme'] = 'scheme'
         uri_parts['user'] = 'user'
@@ -328,8 +334,13 @@ class TestMediaURI(ElisaTestCase):
         uri = media_uri.MediaUri(uri_parts)
         loc = u'scheme://user:password@host.com:80/test- † -html?param2=2&param1=1#truc'
 #        self.assertEqual(uri.path,u'/test- † -html')
+
+        # FIXME: this is not a unit test for the media_uri as it stands and
+        # fails with the not unit tested local_helper.system_encoding method
         self.assertEqual(repr(uri), loc.encode(locale_helper.system_encoding()))
 
+    test_uri_parts.todo = "refactor unittest"
+
     def test_partial_uri_parts(self):
         uri = media_uri.MediaUri({'scheme':'file', 'path': u'/tmp'})
         loc = u'file:///tmp'
