@@ -17,9 +17,9 @@ from twisted.trial import unittest
 from elisa.core.tests.elisa_test_case import ElisaTestCase
 from elisa.core import log
 
-from elisa.base_components.message import Message
+from elisa.core.components.message import Message
 
-from elisa.core.bus import bus
+from elisa.core import bus
 from twisted.internet import defer, reactor
 import platform
 
