@@ -15,11 +15,13 @@
 # for details on that license.
 
 import os
+import tempfile
 
 from elisa.core import common
+from elisa.core import plugin_registry as plugin_registry_module
 from elisa.core.plugin_registry import PluginRegistry, ComponentNotFound, \
         PluginAlreadyEnabled, PluginAlreadyDisabled, InvalidComponentPath, \
-        PluginNotFound
+        PluginNotFound, DeserializationError
 from elisa.core.utils.misc import pkg_resources_copy_dir as copy_dir
 from elisa.core.config import Config
 from twisted.trial.unittest import TestCase
@@ -42,14 +44,43 @@ class FakeBus(object):
     def send_message(self, message):
         self.messages.append(message)
 
+
+class DownloadError(Exception):
+    pass
+
+
+def dummyGetPage(uri):
+    if uri == 'fake-plugin-uri':
+        return defer.succeed('fake-plugin-data')
+    elif uri == 'broken-plugin-uri':
+        return defer.fail(DownloadError())
+    elif uri == 'default-repository':
+        return defer.succeed('[]')
+    elif uri == 'broken-json':
+        return defer.succeed('broken_json')
+    elif uri == 'broken-repository':
+        return defer.fail(DownloadError())
+
+plugin_registry_module.getPage = dummyGetPage
+
 class PluginRegistryMock(PluginRegistry):
     def __init__(self, *args, **kw):
         super(PluginRegistryMock, self).__init__(*args, **kw)
         self.gst_paths = []
+        self._plugin_cache = plugin_registry_module._default_plugin_cache
 
     def _add_gstreamer_path(self, path):
         self.gst_paths.append(path)
 
+    def _get_plugin_cache(self):
+        return self._plugin_cache
+
+    def _set_plugin_cache(self, cache):
+        self._plugin_cache = cache
+
+    plugin_cache = property(_get_plugin_cache, _set_plugin_cache)
+
+
 class TestPluginRegistryMixin(object):
     plugin_registry = None
     old_application = None
@@ -97,9 +128,9 @@ class TestPluginRegistryMixin(object):
         self.old_application = None
 
     def copy_plugins(self):
-        dest_dir = os.path.join(self.test_dir, '0.1/test_simple')
+        dest_dir = os.path.join(self.test_dir, '0.1', 'test_simple')
         copy_dir('elisa.core', 'tests/data/plugins/test_simple-0.1', dest_dir) 
-        dest_dir = os.path.join(self.test_dir, '0.2/test_simple')
+        dest_dir = os.path.join(self.test_dir, '0.2', 'test_simple')
         copy_dir('elisa.core', 'tests/data/plugins/test_simple-0.2', dest_dir) 
 
     def install_plugin(self, link_name, path):
@@ -113,6 +144,7 @@ class TestPluginRegistryMixin(object):
         assert os.path.exists(egg_link)
         os.unlink(egg_link)
 
+
 class TestPluginRegistry(TestPluginRegistryMixin, TestCase):
     plugin_registry = None
 
@@ -120,7 +152,7 @@ class TestPluginRegistry(TestPluginRegistryMixin, TestCase):
         TestPluginRegistryMixin.setUp(self)
          
         # create the PluginRegistry instance used by the tests
-        self.plugin_registry = PluginRegistryMock([self.plugins_dir])
+        self.plugin_registry = PluginRegistryMock(Config(), [self.plugins_dir])
         self.plugin_registry.load_plugins()
 
     def test_import(self):
@@ -130,7 +162,7 @@ class TestPluginRegistry(TestPluginRegistryMixin, TestCase):
         Check that the normal import statement works correctly.
         """
         from elisa.plugins.test_simple.test_module import TestComponent
-    
+
     def test_gstreamer_plugin(self):
         """
         Import a component from a plugin.
@@ -266,12 +298,104 @@ class TestPluginRegistry(TestPluginRegistryMixin, TestCase):
 
     test_hot_upgrade.todo = "Reimplement Hot Upgrade"
 
+    def test_reload_cache(self):
+        self.plugin_registry.plugin_cache = 'non-existant-cache'
+        result = self.plugin_registry.reload_cache()
+        self.failUnlessEquals(result, False)
+
+        self.plugin_registry.plugin_cache = \
+            pkg_resources.resource_filename('elisa.core',
+                                            'tests/data/plugins/plugins.cache')
+        result = self.plugin_registry.reload_cache()
+        self.failUnlessEquals(result, True)
+
+    def test_update_cache(self):
+        self.cache_content = None
+        self.plugin_registry.plugin_cache = os.path.join(self.test_dir,
+                                                         'plugin.cache')
+
+        def test_result(result, expected):
+            self.failUnlessEquals(result, expected)
+            return result
+
+        def remember_cache_content(result):
+            self.cache_content = open(self.plugin_registry.plugin_cache).read()
+
+        def check_cache_content(result):
+            content = open(self.plugin_registry.plugin_cache).read()
+            self.failUnlessEquals(content, self.cache_content)
+
+        def test_good_repository():
+            self.plugin_registry.config['repository'] = 'default-repository'
+            dfr = self.plugin_registry.update_cache()
+            dfr.addCallback(test_result, self.plugin_registry.plugin_cache)
+            dfr.addCallback(remember_cache_content)
+            return dfr
+
+        def test_broken_json(result):
+            self.plugin_registry.config['repository'] = 'broken-json'
+            dfr = self.plugin_registry.update_cache()
+            def failed(failure):
+                failure.trap(DeserializationError)
+            dfr.addErrback(failed)
+            dfr.addCallback(check_cache_content)
+            return dfr
+
+        def test_broken_repository(result):
+            self.plugin_registry.config['repository'] = 'broken-repository'
+            dfr = self.plugin_registry.update_cache()
+            def failed(failure):
+                failure.trap(DownloadError)
+            dfr.addErrback(failed)
+            dfr.addCallback(check_cache_content)
+            return dfr
+
+        dfr = test_good_repository()
+        dfr.addCallback(test_broken_json)
+        dfr.addCallback(test_broken_repository)
+        return dfr
+
+    def test_get_downloadable_plugins(self):
+        # Load a sample cache with describing one plugin
+        self.plugin_registry.plugin_cache = \
+            pkg_resources.resource_filename('elisa.core',
+                                            'tests/data/plugins/plugins.cache')
+        plugins = self.plugin_registry.get_downloadable_plugins(reload_cache=True)
+        self.failUnlessEquals(len(plugins), 1)
+
+        # Load a broken cache
+        self.plugin_registry.plugin_cache = \
+            pkg_resources.resource_filename('elisa.core',
+                                            'tests/data/plugins/plugins.broken_cache')
+        plugins = self.plugin_registry.get_downloadable_plugins(reload_cache=True)
+        self.failUnlessEquals(len(plugins), 0)
+
+    def test_download_plugin(self):
+        plugin_dir = os.path.join(self.test_dir, 'plugins')
+        if not os.path.exists(plugin_dir):
+            os.mkdir(plugin_dir)
+        plugin_registry_module.default_plugin_dirs = [plugin_dir]
+
+        plugin = {'egg_name': 'test.egg',
+                  'uri': 'fake-plugin-uri'}
+        dfr = self.plugin_registry.download_plugin(plugin)
+
+        def test_result(result):
+            egg = os.path.join(plugin_dir, plugin['egg_name'])
+            self.failUnlessEquals(result, egg)
+            self.failUnlessEquals(open(egg).read(), 'fake-plugin-data')
+
+        return dfr.addCallback(test_result)
+
+    test_download_plugin.todo = "Add Varification support to the test"
+
+
 class TestPluginActivation(TestPluginRegistryMixin, TestCase):
     def setUp(self):
         TestPluginRegistryMixin.setUp(self)
 
         # Create the PluginRegistry instance used by the tests
-        self.plugin_registry = PluginRegistry([self.plugins_dir])
+        self.plugin_registry = PluginRegistry(Config(), [self.plugins_dir])
 
         # Disable all the plugins
         plugins = [plugin.key for plugin in pkg_resources.working_set \
@@ -281,6 +405,8 @@ class TestPluginActivation(TestPluginRegistryMixin, TestCase):
         config = common.application.config
         config.set_option('disabled_plugins', ['elisa-plugin-test-simple'],
                           section='general')
+        # No plugin should be enabled
+        return self.plugin_registry.enable_plugins()
 
     def check_disabled_plugins(self, expected):
         config = common.application.config
@@ -288,6 +414,11 @@ class TestPluginActivation(TestPluginRegistryMixin, TestCase):
                                              section='general', default=[])
         self.failUnlessEqual(disabled_plugins, expected)
 
+    def test_get_plugins(self):
+        plugins = [plugin_name for plugin_name, status in \
+                   self.plugin_registry.get_plugins()]
+        self.failUnlessIn('elisa-plugin-test-simple', plugins)
+
     def test_enable_plugin(self):
         def enable_plugin(result):
             plugins = list(self.plugin_registry.get_enabled_plugins())
@@ -416,7 +547,7 @@ class TestPluginActivation(TestPluginRegistryMixin, TestCase):
 
 class TestPluginLoadActivation(TestPluginRegistryMixin, TestCase):
     def test_load_plugins(self):
-        self.plugin_registry = PluginRegistry([self.plugins_dir])
+        self.plugin_registry = PluginRegistry(Config(), [self.plugins_dir])
 
         # Disable all plugins but our test one
         plugins = [plugin.key for plugin in pkg_resources.working_set \
@@ -424,5 +555,11 @@ class TestPluginLoadActivation(TestPluginRegistryMixin, TestCase):
                    plugin.key != 'elisa-plugin-test-simple']
         self.plugin_registry.load_plugins(plugins)
 
-        plugins = list(self.plugin_registry.get_enabled_plugins())
-        self.failUnlessEqual(len(plugins), 1)
+        def check_plugin_activation(result):
+            plugins = list(self.plugin_registry.get_enabled_plugins())
+            self.failUnlessEqual(len(plugins), 1)
+            return result
+
+        dfr = self.plugin_registry.enable_plugins()
+        dfr.addCallback(check_plugin_activation)
+        return dfr
