@@ -26,6 +26,7 @@ from elisa.core.utils.defer import Deferred
 
 import re
 
+
 class FooResourceProvider(ResourceProvider): 
     """
     A stupid providers that just stores the last called method and its
@@ -53,6 +54,7 @@ class FooResourceProvider(ResourceProvider):
     def put(self, *args, **kwargs):
         return self._last_called('put', *args, **kwargs)
 
+
 class TestResourceManager(ElisaTestCase):
 
     def setUp(self):
@@ -63,11 +65,12 @@ class TestResourceManager(ElisaTestCase):
 
         # Set up a test resource manager
         self._manager = ResourceManager()
-        
+
         def provider_created(provider):
             self._test_comp = provider
             # Register the provider
-            self._manager.register_component(self._test_comp)
+            dfr = self._manager.register_component(self._test_comp)
+            return dfr
 
         # Set up a test resource provider
         create_dfr = FooResourceProvider.create()
@@ -81,15 +84,25 @@ class TestResourceManager(ElisaTestCase):
         """
         def provider_created(provider):
             # Register the provider
-            self._manager.register_component(provider)
-            self.failUnless(provider in self._manager._components)
-            uri_regexp = (re.compile(provider.supported_uri), provider)
-            self.failUnless(uri_regexp in self._manager._providers_uri_regexps)
-            # Unregister the provider
-            self._manager.unregister_component(provider)
-            self.failUnless(provider not in self._manager._components)
-            self.failUnless(uri_regexp not in \
-                            self._manager._providers_uri_regexps)
+            dfr = self._manager.register_component(provider)
+
+            def check_provider_registered(result):
+                self.failUnlessIn(provider, self._manager.components)
+
+            def check_uri(result):
+                uri_regexp = (re.compile(provider.supported_uri), provider)
+                self.failUnlessIn(uri_regexp,
+                                  self._manager._providers_uri_regexps)
+
+            def check_provider_unregistered(result):
+                self.failIfIn(provider, self._manager.components)
+
+            dfr.addCallback(check_provider_registered)
+            dfr.addCallback(check_uri)
+            dfr.addCallback(lambda result: \
+                                self._manager.unregister_component(provider))
+            dfr.addCallback(check_provider_unregistered)
+            return dfr
 
         create_dfr = FooResourceProvider.create()
         create_dfr.addCallback(provider_created)
@@ -172,28 +185,26 @@ class TestResourceManager(ElisaTestCase):
 
         non_uris = NoUrisExpression()
         
-        before = len(self._manager._components)
+        before = len(self._manager.components)
         
         self._manager.register_component(non_uris)
-        self.assertEquals(len(self._manager._components), before+1)
+        self.assertEquals(len(self._manager.components), before+1)
 
         self._manager.unregister_component(non_uris)
-        self.assertEquals(len(self._manager._components), before)
+        self.assertEquals(len(self._manager.components), before)
 
         # empty check
         class EmptyUrisExpression(ResourceProvider):
             supported_uri = ''
 
         empty_uris = EmptyUrisExpression()
-        before = len(self._manager._components)
+        before = len(self._manager.components)
         
         self._manager.register_component(empty_uris)
-        self.assertEquals(len(self._manager._components), before+1)
+        self.assertEquals(len(self._manager.components), before+1)
 
         self._manager.unregister_component(empty_uris)
-        self.assertEquals(len(self._manager._components), before)
-
-
+        self.assertEquals(len(self._manager.components), before)
 
     def test_broken_providers(self):
         """
@@ -207,14 +218,13 @@ class TestResourceManager(ElisaTestCase):
         class WrongExpression(ResourceProvider):
             supported_uri = "[]"
 
-        self.assertRaises(Exception, self._manager.register_component,
-                            WrongExpression())
-       
+        dfr = self._manager.register_component(WrongExpression())
+        return self.failUnlessFailure(dfr, Exception)
+
     def test_malformed_parameters(self):
         """
         be sure that the manager fails when you call it with bad data
         """
-
         # try to do it with a string that can't get converted to unicde
         self.assertRaises(UnicodeDecodeError, self._manager.get, '\xcd')
 
@@ -223,26 +233,30 @@ class TestResourceManager(ElisaTestCase):
         Trying to unregister a component, that is not registered is bad
         coding. Make sure that it fails in such a case
         """
-        self.assertRaises(CannotUnregister,
-                          self._manager.unregister_component,
-                          ResourceProvider())
+        dfr = self._manager.unregister_component(ResourceProvider())
+        res_dfr = self.failUnlessFailure(dfr, CannotUnregister)
 
+        def unregister_other_instance(result):
+            # The unregistration is always about the SAME INSTANCE. Passing a
+            # new instance to unregister must fail.
+            class TestProvider(ResourceProvider):
+                supported_uri = 'nothing special'
 
-        # the unregistering is always about the SAME INSTANCE. Passing a new
-        # instance to unregister NEEDS to fail.
-        class TestProvider(ResourceProvider):
-            supported_uri = 'nothing special'
+            test_provider = TestProvider()
+            dfr = self._manager.register_component(test_provider)
 
-        test_provider = TestProvider()
-        self._manager.register_component(test_provider)
+            def try_to_unregister_other_instance(result):
+                dfr = self._manager.unregister_component(TestProvider())
+                res_dfr = self.failUnlessFailure(dfr, CannotUnregister)
 
-        self.assertRaises(CannotUnregister, 
-                          self._manager.unregister_component,
-                          TestProvider())
-        # clean up
-        self._manager.unregister_component(test_provider)
+            dfr.addCallback(try_to_unregister_other_instance)
+            dfr.addCallback(lambda result: \
+                            self._manager.unregister_component(test_provider))
+            return dfr
+
+        res_dfr.addCallback(unregister_other_instance)
+        return res_dfr
 
-                          
     # helper for checking
     def check_result(self, result, method, *args, **kw):
         """
@@ -259,7 +273,6 @@ class TestResourceManager(ElisaTestCase):
         self.assertEquals(self._test_comp.last_arguments, args)
         self.assertEquals(self._test_comp.last_kw, kw)
 
-
     def test_get_resource_provider_by_path(self):
         """
         Test that the get_resource_provider_by_path method works as expected.
