@@ -114,3 +114,10 @@ inlineCallbacks = defer.inlineCallbacks
 DeferredLock = defer.DeferredLock
 DeferredSemaphore = defer.DeferredSemaphore
 DeferredQueue = defer.DeferredQueue
+
+# these classes are new since 8.1
+try:
+    DeferredFilesystemLock = defer.DeferredFilesystemLock
+    AlreadyTryingToLockError = defer.AlreadyTryingToLockError
+except AttributeError:
+    pass
