@@ -21,14 +21,14 @@ when distributing plugins.
 
 __maintainer__ = 'Philippe Normand <philippe@fluendo.com>'
 
-import os
+import os.path
 import sys
 import types
 import shutil
 import tempfile
 
 from elisa.core import config
-from elisa.core.utils import i18n
+from elisa.core.utils import i18n, misc
 from elisa.extern import path
 
 import setuptools
@@ -48,6 +48,8 @@ import pkg_resources
 
 PACKAGE_DATA = {'': ['*.conf', '*.png', '*.mo', '*.po', '*.xml', '*.lirc']}
 
+
+
 class Distribution(SetuptoolsDistribution):
 
     def find_config_files(self):
@@ -218,78 +220,41 @@ def write_dict(cmd, basename, filename, force=False):
     cmd.write_or_delete_file(argname, filename, text_value, force)
 
 
-def mappings_from_text(text):
-    """
-    Unserialise mappings from a string L{text}. Mappings are lists of 2-uplets.
-
-    Example::
-
-        key1 = value1
-        key2 = value2a
-        key2 = value2b
-
-    is deserialised into::
-
-        [("key1", "value1"), ("key2", "value2a"), ("key2", "value2b")]
-    """
-    mappings = []
-    if text != None:
-        for line in text.splitlines():
-            m = tuple([elt.strip() for elt in line.split('=')])
-            if len(m) != 2: 
-                raise ValueError
-            mappings.append(m)
-
-    return mappings
-
-def text_from_mappings(mappings):
-    """
-    Takes a L{mappings} and return a serialised form. Mappings are list of
-    2-uplets.
-
-    Example::
-
-        [("key1", "value1"), ("key2", "value2a"), ("key2", "value2b")]
-
-    is serialised into::
-
-        key1 = value1
-        key2 = value2a
-        key2 = value2b
-    """
-    text = ""
-    if mappings != None:
-        for key, value in mappings:
-            text += "%s = %s%s" % (key, value, os.linesep)
-
-    return text
-
-def read_mappings(iter_lines):
-    """
-    Setuptools compliant deserialiser for mappings.
-    """
-    text = os.linesep.join(iter_lines)
-    return mappings_from_text(text)
-
 def write_mappings(cmd, basename, filename, force=False):
     """
     Setuptools compliant serialiser for mappings.
     """
     argname = os.path.splitext(basename)[0]
     arg_value = getattr(cmd.distribution, argname, None)
-    text_value = text_from_mappings(arg_value)
+    text_value = misc.text_from_mappings(arg_value)
     cmd.write_or_delete_file(argname, filename, text_value, force)
 
+
+def _all(iterable):
+    try:
+        return all(iterable)
+    except NameError:
+        # The all builtin is new in Python 2.5
+        # (see http://www.python.org/doc/2.5.2/lib/built-in-funcs.html#l2h-9)
+        for element in iterable:
+            if not element:
+                return False
+        return True
+
+
 def assert_list_of_string_tuples_or_none(dist, attr, value):
     """Verify that value is a list of tuples of string"""
     if type(value) is types.NoneType:
         return
     if type(value) is list:
         for item in value:
-            valid = type(item) is tuple and all([type(e) is str for e in item])
+            valid = type(item) is tuple and \
+                    _all([type(e) is str for e in item])
             if not valid:
-                raise DistutilsSetupError("%r must be a list of tuples of string or "\
-                                          "None value. Got %r" % (attr,value))
+                raise DistutilsSetupError("%r must be a list of tuples of " \
+                                          "strings or None. Got %r" \
+                                          % (attr, value))
+
 
 def assert_dict_or_none(dist, attr, value):
     """Verify that value is a dictionary"""
@@ -443,6 +408,9 @@ class build_po(Command):
         pass
 
     def run(self):
-        mo_files = i18n.compile_po_files(self.distribution.get_name(), 'i18n', 'i18n',
+        setup_path = os.path.dirname(sys.argv[0])
+        po_path = os.path.join(setup_path, 'i18n')
+        mo_files = i18n.compile_po_files(self.distribution.get_name(),
+                                         po_path, po_path,
                                          announce_func=self.announce)
         self.distribution.package_data.update(mo_files)
