@@ -25,6 +25,8 @@ reasonnably small.
 import mimetypes
 import sys, platform
 import os, re
+import subprocess
+
 from twisted.internet import defer
 from twisted.trial.unittest import SkipTest
 
@@ -36,6 +38,10 @@ functional tests
 """
 FUNCTIONAL_TESTS_STR = 'RUN_FUNCTIONAL_TESTS'
 
+# Use the same line separator on all the platforms (yes, including Windows)
+LINESEP = '\n'
+
+
 def env_var_expand(var_name):
     """
     Expand the given environment variable content. If it contains
@@ -153,28 +159,50 @@ def is_hildon_desktop_running():
     return _hildon_desktop_running
 
 def get_distro():
-    return "UME HP 1.0"
+    if platform.system() == 'Windows':
+        platform_name = platform.platform()
+        # example os_name = Windows, os_version = Vista
+        os_name, os_version = platform_name.split('-')[:2]
+        distro = ' '.join([os_name, os_version])
+    else:
+        try:
+            output = subprocess.Popen(["lsb_release", "-a"],
+                                      stderr=subprocess.STDOUT,
+                                      stdout=subprocess.PIPE).communicate()[0]
+        except OSError, error:
+            # lsb_release program not found, let's use a crappy method.
+            known_distros = {"Debian" : "/etc/debian_version",
+                             #"RedHat" : "/etc/redhat-release",
+                             "SUSE" : "/etc/SUSE-release",
+                             "Fedora" : "/etc/fedora-release",
+                             "Gentoo" : "/etc/gentoo-release",
+                             "Slackware" : "/etc/slackware-version",
+                             "Mandrake" : "/etc/mandrake-release",
+                             "YellowDog" : "/etc/yellowdog-release",
+                             "SUN JDS" : "/etc/sun-release",
+                             "UnitedLinux" : "/etc/UnitedLinux-release"
+                             }
+            distro = 'Unknown'
+            for name, location in known_distros.iteritems():
+                if os.path.exists(location):
+                    distro = name
+                    break
+        else:
+            distro_infos = {}
+            lines = output.splitlines()
+            for line in lines:
+                try:
+                    key, value = line.split(':')
+                except ValueError:
+                    continue
+                # strip \t
+                value = value[1:]
+                distro_infos[key] = value
 
-    DISTROS = {
-        "Ubuntu" : "/etc/lsb-release",
-        "Debian" : "/etc/debian_version",
-        #"RedHat" : "/etc/redhat-release",
-        "SUSE" : "/etc/SUSE-release",
-        "Fedora" : "/etc/fedora-release",
-        "Gentoo" : "/etc/gentoo-release",
-        "Slackware" : "/etc/slackware-version",
-        "Mandriva" : "/etc/mandriva-release",
-        "Mandrake" : "/etc/mandrake-release",
-        "YellowDog" : "/etc/yellowdog-release",
-        "SUN JDS" : "/etc/sun-release",
-        "UnitedLinux" : "/etc/UnitedLinux-release"
-    }
-
-    for name, location in DISTROS.iteritems():
-        if os.path.exists(location):
-            return name
-    return 'Unknown'
+            distro = distro_infos['Distributor ID']
+            # TODO: maybe make use of Release information (Intrepid, Hardy, 2009, etc)
 
+    return distro
 
 def get_os_name():
     distro = get_distro()
@@ -249,17 +277,57 @@ def chainDeferredIgnoringResult(first, chained):
 
     first.addCallbacks(cb, eb)
 
-def callAfterDeferredCalled(dfr, method, *args, **kw):
-    retry_callback = kw.get('retry_callback', None)
-    if retry_callback is None:
-        def retry(result_or_failure):
-            return method(*args, **kw)
 
-        retry_callback = retry
+def mappings_from_text(text):
+    """
+    Unserialise mappings from a string L{text}. Mappings are lists of 2-uplets.
 
-    new_dfr = defer.Deferred()
-    new_dfr.addBoth(retry_callback)
+    Example::
 
-    chainDeferredIgnoringResult(dfr, new_dfr)
+        key1 = value1
+        key2 = value2a
+        key2 = value2b
+
+    is deserialised into::
+
+        [("key1", "value1"), ("key2", "value2a"), ("key2", "value2b")]
+    """
+    mappings = []
+    if text != None:
+        for line in text.splitlines():
+            m = tuple([elt.strip() for elt in line.split('=')])
+            if len(m) != 2: 
+                raise ValueError
+            mappings.append(m)
+
+    return mappings
+
+def text_from_mappings(mappings):
+    """
+    Takes a L{mappings} and return a serialised form. Mappings are list of
+    2-uplets.
+
+    Example::
+
+        [("key1", "value1"), ("key2", "value2a"), ("key2", "value2b")]
+
+    is serialised into::
+
+        key1 = value1
+        key2 = value2a
+        key2 = value2b
+    """
+    text = ""
+    if mappings != None:
+        for key, value in mappings:
+            text += "%s = %s%s" % (key, value, LINESEP)
+
+    return text
+
+def read_mappings(iter_lines):
+    """
+    Setuptools compliant deserialiser for mappings.
+    """
+    text = LINESEP.join(iter_lines)
+    return mappings_from_text(text)
 
-    return new_dfr
